/**
 * JASMINe
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ConfEditorService.java 5142 2009-09-04 13:24:13Z merisiec $
 * --------------------------------------------------------------------------
 */

package org.ow2.jasmine.monitoring.eos.confeditor.service;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.io.Serializable;

import org.ow2.jasmine.monitoring.eos.common.JasmineEventManager;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

public class ConfEditorService implements Serializable {

    /**
     *  serialVersionUID.
     */
    private static final long serialVersionUID = -1254916345191626735L;

    /**
     * Logger.
     */
    private static Log logger = LogFactory.getLog(ConfEditorService.class);

    /**
     * The event manager instance.
     */
    private JasmineEventManager manager = null;

    public ConfEditorService() {
        this.manager = new JasmineEventManager();
    }

    /**
     * Load an xml file to configure graphs.
     *
     * @param file the xml file to load
     * @return a string representing the xml file, without the header.
     */
    public String loadFile(final String file) {
        String result = "";
        FileReader f = null;
        BufferedReader buffer = null;
        try {

            String line = "";

            f = new FileReader(file);

            buffer = new BufferedReader(f);

            boolean write = false;

            while ((line = buffer.readLine()) != null) {
                if (line.contains("<monitor")) {
                    write = true;
                }
                if (write) {
                    result += line + "\n";
                }
            }

            return result;

        } catch (FileNotFoundException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        } catch (IOException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        } finally {
            try {
                buffer.close();
                f.close();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }

        return "";

    }

}
